
MAKE=make
CP=cp -f
RM=rm -f
MKDIR=mkdir -p
ECHO=echo

TOP=.
OUT_D=$(TOP)/out_dll
TMP_D=$(TOP)/tmp_dll

O_SSL=$(OUT_D)/libssl_s.a
O_CRYPTO=$(OUT_D)/libcrypto_s.a
L_SSL=$(OUT_D)/libssl_dll.a
L_CRYPTO=$(OUT_D)/libcrypto_dll.a
SO_SSL=$(OUT_D)/kssl10.dll
SO_CRYPTO=$(OUT_D)/kcrypt10.dll

CRYPTO_TEMPLATE_DEF=$(TOP)/os2/ossl10_crypto_os2knix.def
CRYPTO_DEF=$(TMP_D)/crypto.def
SSL_TEMPLATE_DEF=$(TOP)/os2/ossl10_ssl_os2knix.def
SSL_DEF=$(TMP_D)/ssl.def

MAKEFILE_OS2=$(TOP)/os2/OS2-KNIX-gcc.mak
MAKEFILE_APPS=Makefile.apps-os2knix
APPS_SED=$(TOP)/os2/apps_os2knix.sed


LDFLAGS=-s -Zmt -Zomf -Zstack 8192
SHARED_LDFLAGS=-s -Zmt -Zdll -Zomf

EX_LIBS=-lsocket -lz

all: $(SO_CRYPTO) $(SO_SSL) $(L_CRYPTO) $(L_SSL) app tools

install_sw:
	$(MAKE) -C $(TOP) "LDFLAGS=$(LDFLAGS)" "EX_LIBS=$(EX_LIBS)" "EXE_EXT=.exe" install_sw

tools: $(TOP)/libcrypto.a $(TOP)/libssl.a
	$(MAKE) -C $(TOP) "LDFLAGS=$(LDFLAGS)" "EX_LIBS=$(EX_LIBS)" "EXE_EXT=.exe" build_tools

app: $(OUT_D)/openssl.exe

openssl.pc: $(TOP)/libcrypto.a $(TOP)/libssl.a $(OUT_D)/openssl.exe
	$(MAKE) -C $(TOP) "EXE_EXT=.exe" libcrypto.pc libssl.pc openssl.pc

mkapps: $(TMP_D)/$(MAKEFILE_APPS)

$(L_SSL): $(SSL_DEF)
	emximp -o $@ $<

$(L_CRYPTO): $(CRYPTO_DEF)
	emximp -o $@ $<

$(SO_CRYPTO): $(O_CRYPTO) $(CRYPTO_DEF)
	gcc $(SHARED_LDFLAGS) -o $@ $(O_CRYPTO) $(CRYPTO_DEF) $(EX_LIBS)

$(SO_SSL): $(O_SSL) $(L_CRYPTO) $(SSL_DEF)
	gcc $(SHARED_LDFLAGS) -o $@ $(O_SSL) $(L_CRYPTO) $(SSL_DEF) $(EX_LIBS)

$(SSL_DEF): $(SSL_TEMPLATE_DEF) $(O_SSL)
	-$(MKDIR) $(TMP_D)
	$(CP) $(SSL_TEMPLATE_DEF) $@
	$(ECHO) "EXPORTS" >> $@
	emxexp $(O_SSL) >> $@

$(CRYPTO_DEF): $(CRYPTO_TEMPLATE_DEF) $(O_CRYPTO)
	-$(MKDIR) $(TMP_D)
	$(CP) $(CRYPTO_TEMPLATE_DEF) $@
	$(ECHO) "EXPORTS" >> $@
	emxexp $(O_CRYPTO) >> $@

$(O_SSL): $(TOP)/libssl.a
	-$(MKDIR) $(OUT_D)
	$(CP) $< $@

$(O_CRYPTO): $(TOP)/libcrypto.a
	-$(MKDIR) $(OUT_D)
	$(CP) $< $@

$(TMP_D)/$(MAKEFILE_APPS): $(TOP)/apps/Makefile $(MAKEFILE_OS2)
	$(ECHO) "OUT ?= out_dll" > $@
	$(ECHO) "LDFLAGS ?= $(LDFLAGS)" >> $@
	sed -f $(APPS_SED) < $< >> $@

$(TOP)/libcrypto.a: $(TOP)/Makefile
	$(MAKE) -C $(TOP) build_crypto build_engines "LDFLAGS=$(LDFLAGS)" "EX_LIBS=$(EX_LIBS)" "EXE_EXT=.exe"

$(TOP)/libssl.a: $(TOP)/Makefile
	$(MAKE) -C $(TOP) build_ssl "LDFLAGS=$(LDFLAGS)" "EX_LIBS=$(EX_LIBS)" "EXE_EXT=.exe"

$(OUT_D)/openssl.exe: $(TOP)/Makefile $(TMP_D)/$(MAKEFILE_APPS) $(L_SSL) $(L_CRYPTO) openssl.pc
	$(MAKE) -C $(TOP) build_apps "LDFLAGS=$(LDFLAGS)" "EX_LIBS=$(EX_LIBS)" "EXE_EXT=.exe"
	@$(MKDIR) $(OUT_D)/bin_static
	$(CP) apps/openssl.exe $(OUT_D)/bin_static
	$(MAKE) -C apps -f ../tmp_dll/$(MAKEFILE_APPS) "OUT=../out_dll" "LDFLAGS=$(LDFLAGS)" "EX_LIBS=$(EX_LIBS)" "EXE_EXT=.exe" exe


